fastreid.data
=======================

.. automodule:: fastreid.data.build
    :members:
    :undoc-members:
    :show-inheritance:


fastreid.data.data\_utils module
---------------------------------------

.. automodule:: fastreid.data.data_utils
    :members:
    :undoc-members:
    :show-inheritance:


fastreid.data.datasets module
---------------------------------------

.. automodule:: fastreid.data.datasets.market1501
    :members:

.. automodule:: fastreid.data.datasets.cuhk03
    :members:

.. automodule:: fastreid.data.datasets.dukemtmcreid
    :members:

.. automodule:: fastreid.data.datasets.msmt17
    :members:

.. automodule:: fastreid.data.datasets.AirportALERT
    :members:

.. automodule:: fastreid.data.datasets.iLIDS
    :members:

.. automodule:: fastreid.data.datasets.pku
    :members:

.. automodule:: fastreid.data.datasets.prai
    :members:

.. automodule:: fastreid.data.datasets.saivt
    :members:

.. automodule:: fastreid.data.datasets.sensereid
    :members:

.. automodule:: fastreid.data.datasets.sysu_mm
    :members:

.. automodule:: fastreid.data.datasets.thermalworld
    :members:

.. automodule:: fastreid.data.datasets.pes3d
    :members:

.. automodule:: fastreid.data.datasets.caviara
    :members:

.. automodule:: fastreid.data.datasets.viper
    :members:

.. automodule:: fastreid.data.datasets.lpw
    :members:

.. automodule:: fastreid.data.datasets.shinpuhkan
    :members:

.. automodule:: fastreid.data.datasets.wildtracker
    :members:

.. automodule:: fastreid.data.datasets.cuhk_sysu
    :members:


fastreid.data.samplers module
---------------------------------------

.. automodule:: fastreid.data.samplers
    :members:
    :undoc-members:
    :show-inheritance:


fastreid.data.transforms module
---------------------------------------

.. automodule:: fastreid.data.transforms
    :members:
    :undoc-members:
    :show-inheritance:
    :imported-members:
